<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>AdvSearch</name>
    <message>
        <source>All clauses</source>
        <translation>Visos sąlygos</translation>
    </message>
    <message>
        <source>Any clause</source>
        <translation>Bet kuri sąlyga</translation>
    </message>
    <message>
        <source>texts</source>
        <translation>tekstai</translation>
    </message>
    <message>
        <source>spreadsheets</source>
        <translation>skaičiuoklės</translation>
    </message>
    <message>
        <source>presentations</source>
        <translation>prezentacijos</translation>
    </message>
    <message>
        <source>media</source>
        <translation>media</translation>
    </message>
    <message>
        <source>messages</source>
        <translation>žinutės</translation>
    </message>
    <message>
        <source>other</source>
        <translation>kita</translation>
    </message>
    <message>
        <source>Bad multiplier suffix in size filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvSearchBase</name>
    <message>
        <source>Advanced search</source>
        <translation>Išsamesnė paieška</translation>
    </message>
    <message>
        <source>Search for &lt;br&gt;documents&lt;br&gt;satisfying:</source>
        <translation>Ieškoti &lt;br&gt;dokumentų&lt;br&gt;tenkinančių:</translation>
    </message>
    <message>
        <source>Delete clause</source>
        <translation>Ištrinti sąlygą</translation>
    </message>
    <message>
        <source>Add clause</source>
        <translation>Pridėti sąlygą</translation>
    </message>
    <message>
        <source>Restrict file types</source>
        <translation>Apriboti bylų tipus</translation>
    </message>
    <message>
        <source>Check this to enable filtering on file types</source>
        <translation>Pažymėti, jei norite filtruoti pagal bylų tipus</translation>
    </message>
    <message>
        <source>By categories</source>
        <translation>Pagal kategorijas</translation>
    </message>
    <message>
        <source>Check this to use file categories instead of raw mime types</source>
        <translation>Pažymėti, jei norite naudoti bylų kategorijas vietoje mime tipų</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Išsaugoti kaip numatytąjį</translation>
    </message>
    <message>
        <source>Searched file types</source>
        <translation>Ieškota bylų tipų</translation>
    </message>
    <message>
        <source>All ----&gt;</source>
        <translation>Visi ----&gt;</translation>
    </message>
    <message>
        <source>Sel -----&gt;</source>
        <translation>Pas -----&gt;</translation>
    </message>
    <message>
        <source>&lt;----- Sel</source>
        <translation>&lt;----- Pas</translation>
    </message>
    <message>
        <source>&lt;----- All</source>
        <translation>&lt;----- Visi</translation>
    </message>
    <message>
        <source>Ignored file types</source>
        <translation>Ignoruoti bylų tipai</translation>
    </message>
    <message>
        <source>Enter top directory for search</source>
        <translation>Įrašykite viršutinio lygio direktoriją paieškai</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Naršyti</translation>
    </message>
    <message>
        <source>Restrict results to files in subtree:</source>
        <translation>Pateikti rezultatus byloms submedyje:</translation>
    </message>
    <message>
        <source>Start Search</source>
        <translation>Pradėti paiešką</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Uždaryti</translation>
    </message>
    <message>
        <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
        <translation>Visi kairėje esantys netušti laukai bus sujungiami AND (visi) arba OR (bet kuris) pagalba. &lt;br&gt; &quot;Bet kuris&quot; &quot;Visi&quot; ir &quot;Nei vienas&quot; laukų tipai gali priimti paprastų žodžių mišinį ir frazes pažymėtas dvigubomis kabutėmis. &lt;br&gt; Tušti laukeliai ignoruojami.</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum size. You can use k/K,m/M,g/G as multipliers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Min. Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum size. You can use k/K,m/M,g/G as multipliers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable filtering on dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable filtering on sizes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter sizes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CronToolW</name>
    <message>
        <source>Cron Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; batch indexing schedule (cron) &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Each field can contain a wildcard (*), a single numeric value, comma-separated lists (1,3,5) and ranges (1-7). More generally, the fields will be used &lt;span style=&quot; font-style:italic;&quot;&gt;as is&lt;/span&gt; inside the crontab file, and the full crontab syntax can be used, see crontab(5).&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;For example, entering &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;*&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Days, &lt;/span&gt;&lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;12,19&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Hours&lt;/span&gt; and &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;15&lt;/span&gt; in &lt;span style=&quot; font-style:italic;&quot;&gt;Minutes&lt;/span&gt; would start recollindex every day at 12:15 AM and 7:15 PM&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A schedule with very frequent activations is probably less efficient than real time indexing.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Days of week (* or 0-7, 0 or 7 is Sunday)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours (* or 0-23)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minutes (0-59)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Click &lt;span style=&quot; font-style:italic;&quot;&gt;Disable&lt;/span&gt; to stop automatic batch indexing, &lt;span style=&quot; font-style:italic;&quot;&gt;Enable&lt;/span&gt; to activate it, &lt;span style=&quot; font-style:italic;&quot;&gt;Cancel&lt;/span&gt; to change nothing.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems that manually edited entries exist for recollindex, cannot edit crontab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error installing cron entry. Bad syntax in fields ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FirstIdxDialog</name>
    <message>
        <source>First indexing setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;It appears that the index for this configuration does not exist.&lt;/span&gt;&lt;br /&gt;&lt;br /&gt;If you just want to index your home directory with a set of reasonable defaults, press the &lt;span style=&quot; font-style:italic;&quot;&gt;Start indexing now&lt;/span&gt; button. You will be able to adjust the details later. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;If you want more control, use the following links to adjust the indexing configuration and schedule.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;These tools can be accessed later from the &lt;span style=&quot; font-style:italic;&quot;&gt;Preferences&lt;/span&gt; menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will let you adjust the directories you want to index, and other parameters like excluded file paths or names, default character sets, etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will let you chose between batch and real-time indexing, and set up an automatic  schedule for batch indexing (using cron).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start indexing now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IdxSchedW</name>
    <message>
        <source>Index scheduling setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; indexing can run permanently, indexing files as they change, or run at discrete intervals. &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Reading the manual may help you to decide between these approaches (press F1). &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This tool can help you set up a schedule to automate batch indexing runs, or start real time indexing when you log in (or both, which rarely makes sense). &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cron scheduling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The tool will let you decide at what time indexing should run and will install a crontab entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Real time indexing start up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decide if real time indexing will be started when you log in (only for the default index).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GroupBox</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Configuration problem (dynconf</source>
        <translation type="obsolete">Nustatymų bėda (dynconf</translation>
    </message>
    <message>
        <source>No db directory in configuration</source>
        <translation>Nustatymuose nerandama duomenų bazės bylos</translation>
    </message>
    <message>
        <source>Could not open database in </source>
        <translation type="obsolete">Nepavyko atidaryti duomenų bazės</translation>
    </message>
    <message>
        <source>&quot;history&quot; file is damaged or un(read)writeable, please check or remove it: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preview</name>
    <message>
        <source>Close Tab</source>
        <translation>Uždarykite auselę</translation>
    </message>
    <message>
        <source>Cannot create temporary directory</source>
        <translation type="obsolete">Nepavyksta sukurti laikinos direktorijos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atšaukti</translation>
    </message>
    <message>
        <source>Missing helper program: </source>
        <translation>Trūksta pagalbinės programos:</translation>
    </message>
    <message>
        <source>Can&apos;t turn doc into internal representation for </source>
        <translation>Nepavyksta pervesti dokumento į vidinę buseną</translation>
    </message>
    <message>
        <source>Creating preview text</source>
        <translation>Kuriamas peržvalgos tekstas</translation>
    </message>
    <message>
        <source>Loading preview text into editor</source>
        <translation>Įkeliamas į redaktorių peržvalgos tekstas</translation>
    </message>
    <message>
        <source>&amp;Search for:</source>
        <translation>&amp;Ieškoti:</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Sekantis</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Ankstesnis</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
    <message>
        <source>Match &amp;Case</source>
        <translation>Atitaikyti &amp;Atvejį </translation>
    </message>
    <message>
        <source>Cannot create temporary directory: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while loading file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewTextEdit</name>
    <message>
        <source>Show fields</source>
        <translation>Rodyti laukus</translation>
    </message>
    <message>
        <source>Show main text</source>
        <translation>Rodyti pagrindinį tekstą</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Print Current Preview</source>
        <translation>Spausdinti kaip matoma peržiūroje</translation>
    </message>
    <message>
        <source>Show image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save document to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fold lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preserve indentation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Global parameters</source>
        <translation>Globalūs parametrai</translation>
    </message>
    <message>
        <source>Local parameters</source>
        <translation>Lokalūs parametrai</translation>
    </message>
    <message>
        <source>&lt;b&gt;Customised subtrees</source>
        <translation>&lt;b&gt;Pritaikyti direktorijų&lt;br&gt; submedžiai</translation>
    </message>
    <message>
        <source>The list of subdirectories in the indexed hierarchy &lt;br&gt;where some parameters need to be redefined. Default: empty.</source>
        <translation>Subdirektorijų, kuriose dalį parametrų reikia pakeisti, sąrašas.&lt;br&gt; Numatytoji reikšmė: tuščia.</translation>
    </message>
    <message>
        <source>&lt;i&gt;The parameters that follow are set either at the top level, if nothing&lt;br&gt;or an empty line is selected in the listbox above, or for the selected subdirectory.&lt;br&gt;You can add or remove directories by clicking the +/- buttons.</source>
        <translation>&lt;i&gt;Nurodyti parametrai taikomi arba visoms direktorijoms, arba subdirektorijoms,&lt;br&gt; jei kuri jų prieš tai pažymimos. Pridėti ir ištrinti direktorijų vardus galite&lt;br&gt; spausdami +/- mygtukus.</translation>
    </message>
    <message>
        <source>Skipped names</source>
        <translation>Neįtraukti vardai</translation>
    </message>
    <message>
        <source>These are patterns for file or directory  names which should not be indexed.</source>
        <translation>Bylų arba direktorijų, kurių nedera indeksuoti, vardų šablonai.</translation>
    </message>
    <message>
        <source>Default character set</source>
        <translation>Numatytoji simbolių aibė</translation>
    </message>
    <message>
        <source>This is the character set used for reading files which do not identify the character set internally, for example pure text files.&lt;br&gt;The default value is empty, and the value from the NLS environnement is used.</source>
        <translation>Pasirinkta simbolių aibė bus naudojama skaityti bylų, kurių simbolių aibės nepavyksta nustatyti, turiniui.&lt;br&gt;Numatytoji vertė yra nepasirinkti konkrečios simbolių aibės - tokiu atveju naudojama NLS aplinkos vertė.</translation>
    </message>
    <message>
        <source>Follow symbolic links</source>
        <translation>Sekti simbolines nuorodas</translation>
    </message>
    <message>
        <source>Follow symbolic links while indexing. The default is no, to avoid duplicate indexing</source>
        <translation>Indeksavimo metu sekti simbolines nuorodas. Numatytasis elgesys yra nesekti, bandant išvengti dvigubo indeksavimo</translation>
    </message>
    <message>
        <source>Index all file names</source>
        <translation>Indeksuoti visų bylų vardus</translation>
    </message>
    <message>
        <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
        <translation>Indeksuoti bylų, kurių turinio nepavyksta perskaityti, vardus. Numatytoji reikšmė: teisybė</translation>
    </message>
    <message>
        <source>Beagle web history</source>
        <translation>Beagle tinklo istorija</translation>
    </message>
</context>
<context>
    <name>RTIToolW</name>
    <message>
        <source>Real time indexing automatic start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Recoll&lt;/span&gt; indexing can be set up to run as a daemon, updating the index as files change, in real time. You gain an always up to date index, but system resources are used permanently.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start indexing daemon with my desktop session.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also start indexing daemon right now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t create: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Įspėjimas</translation>
    </message>
    <message>
        <source>Could not execute recollindex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Removing autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autostart file deleted. Kill current process too ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMain</name>
    <message>
        <source>(no stemming)</source>
        <translation>(no stemming)</translation>
    </message>
    <message>
        <source>(all languages)</source>
        <translation>(visos kalbos)</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>error retrieving stemming languages</translation>
    </message>
    <message>
        <source>Indexing in progress: </source>
        <translation>Indeksuojama:</translation>
    </message>
    <message>
        <source>Files</source>
        <translation type="obsolete">Failai</translation>
    </message>
    <message>
        <source>Purge</source>
        <translation>Išvalyti</translation>
    </message>
    <message>
        <source>Stemdb</source>
        <translation>Stemdb</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Uždaroma</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nežinoma</translation>
    </message>
    <message>
        <source>Can&apos;t start query: </source>
        <translation type="obsolete">Nepavyksta pradėti vykdyti užklausą:</translation>
    </message>
    <message>
        <source>Query results</source>
        <translation>Užklausos rezultatai</translation>
    </message>
    <message>
        <source>Cannot retrieve document info from database</source>
        <translation>Nepavyksta išgauti iš duomenų bazės informacijos apie dokumentą </translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Įspėjimas</translation>
    </message>
    <message>
        <source>Can&apos;t create preview window</source>
        <translation>Nepavyksta sukurti peržiūros lango</translation>
    </message>
    <message>
        <source>This search is not active any more</source>
        <translation>Ši paieška daugiau nevykdoma</translation>
    </message>
    <message>
        <source>Bad viewer command line for %1: [%2]
Please check the mimeconf file</source>
        <translation>Netinkamos peržiūros komandinė eilutė  %1: [%2]
Prašome patikrinti mimeconf bylą</translation>
    </message>
    <message>
        <source>Cannot extract document or create temporary file</source>
        <translation>Nepavyksta perskaityti dokumento arba sukurti laikinos bylos</translation>
    </message>
    <message>
        <source>Executing: [</source>
        <translation>Vykdoma: [</translation>
    </message>
    <message>
        <source>About Recoll</source>
        <translation>Apie Recoll</translation>
    </message>
    <message>
        <source>History data</source>
        <translation>Istorijos duomenys</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Dokumentų istorija</translation>
    </message>
    <message>
        <source>Update &amp;Index</source>
        <translation>Atnaujinti &amp;Indeksą</translation>
    </message>
    <message>
        <source>Indexing interrupted</source>
        <translation type="obsolete">indeksavimas pertrauktas</translation>
    </message>
    <message>
        <source>Stop &amp;Indexing</source>
        <translation>Sustabdyti &amp;Indeksavimą</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Visi</translation>
    </message>
    <message>
        <source>media</source>
        <translation>media</translation>
    </message>
    <message>
        <source>message</source>
        <translation>pranešimas</translation>
    </message>
    <message>
        <source>other</source>
        <translation>kita</translation>
    </message>
    <message>
        <source>presentation</source>
        <translation>prezentacijos</translation>
    </message>
    <message>
        <source>spreadsheet</source>
        <translation>skaičiuoklės</translation>
    </message>
    <message>
        <source>text</source>
        <translation>tekstas</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation>surūšiuota</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation>filtruotas</translation>
    </message>
    <message>
        <source>External applications/commands needed and not found for indexing your file types:

</source>
        <translation>Reikalingos pilnam indeksavimui, tačiau nerandamos išorinės programos/komandos: 

</translation>
    </message>
    <message>
        <source>No helpers found missing</source>
        <translation>Randamos visos reikalingos pagalbinės programos</translation>
    </message>
    <message>
        <source>Missing helper programs</source>
        <translation>Trūksta pagalbinių programų</translation>
    </message>
    <message>
        <source>Save file dialog</source>
        <translation type="obsolete">Išsaugoti failą forma</translation>
    </message>
    <message>
        <source>Choose a file name to save under</source>
        <translation type="obsolete">Pasirinkite bylos vardą, kuriuo išsaugosite bylą</translation>
    </message>
    <message>
        <source>Document category filter</source>
        <translation>Dokumentų kategorijų filtras</translation>
    </message>
    <message>
        <source>No external viewer configured for mime type [</source>
        <translation>Nustatymuose nenumatyta jokia išorinė peržiūros programa šiam mime tipui [</translation>
    </message>
    <message>
        <source>The viewer specified in mimeview for %1: %2 is not found.
Do you want to start the  preferences dialog ?</source>
        <translation>Nurodyta peržiūros programa šiam mime tipui %1: %2 nerandama.
Ar norėtumete iššaukti nustatymų langą?</translation>
    </message>
    <message>
        <source>Can&apos;t access file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t uncompress file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result count (est.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="unfinished">Užklausos detalės</translation>
    </message>
    <message>
        <source>Could not open external index. Db not open. Check external indexes list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No results found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Updating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexing failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current indexing process was not started from this interface. Click Ok to kill it anyway, or Cancel to leave it alone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erasing index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset the index and start from scratch ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query in progress.&lt;br&gt;Due to limitations of the indexing library,&lt;br&gt;cancelling will exit the program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index not open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index query error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content has been indexed for these mime types:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index not up to date for this file. Refusing to risk showing the wrong entry. Click Ok to update the index for this file, then re-run the query when indexing is done. Else, Cancel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t update index: indexer running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indexed MIME Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RclMainBase</name>
    <message>
        <source>Recoll</source>
        <translation>Recoll</translation>
    </message>
    <message>
        <source>Search tools</source>
        <translation>Paieškos įrankiai</translation>
    </message>
    <message>
        <source>Result list</source>
        <translation>Rezultatų sąrašas</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Byla</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Įrankiai</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>I&amp;šeiti</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Update &amp;index</source>
        <translation>Atnaujinti &amp;Indeksą</translation>
    </message>
    <message>
        <source>&amp;Erase document history</source>
        <translation>&amp;Ištrinti dokumentų istoriją</translation>
    </message>
    <message>
        <source>&amp;About Recoll</source>
        <translation>&amp;Apie Recoll</translation>
    </message>
    <message>
        <source>&amp;User manual</source>
        <translation>&amp;Vartotojo vadovas</translation>
    </message>
    <message>
        <source>Document &amp;History</source>
        <translation>Dokumentų &amp;Istorija</translation>
    </message>
    <message>
        <source>Document  History</source>
        <translation>Dokumentų Istorija</translation>
    </message>
    <message>
        <source>&amp;Advanced Search</source>
        <translation>&amp;Išsamesnė Paieška</translation>
    </message>
    <message>
        <source>Advanced/complex  Search</source>
        <translation>Išsamesnė Paieška</translation>
    </message>
    <message>
        <source>&amp;Sort parameters</source>
        <translation>&amp;Surūšiuoti parametrai</translation>
    </message>
    <message>
        <source>Sort parameters</source>
        <translation>Surūšiuoti parametrus</translation>
    </message>
    <message>
        <source>Term &amp;explorer</source>
        <translation>Raktinių žodžių &amp;tyrinėtojas</translation>
    </message>
    <message>
        <source>Term explorer tool</source>
        <translation>Raktinių žodžių tyrinėjimo įrankis</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Sekantis puslapis</translation>
    </message>
    <message>
        <source>Next page of results</source>
        <translation>Sekantis rezultatų puslapis</translation>
    </message>
    <message>
        <source>First page</source>
        <translation>Pirmas puslapis</translation>
    </message>
    <message>
        <source>Go to first page of results</source>
        <translation>Pereiti į pirmą rezultatų puslapį</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Prieš tai buvęs puslapis</translation>
    </message>
    <message>
        <source>Previous page of results</source>
        <translation>Ankstesnis rezultatų puslapis</translation>
    </message>
    <message>
        <source>&amp;Query configuration</source>
        <translation>&amp;Užklausų nustatymai</translation>
    </message>
    <message>
        <source>External index dialog</source>
        <translation>Išorinių indeksų langas</translation>
    </message>
    <message>
        <source>&amp;Indexing configuration</source>
        <translation>&amp;Indeksavimo nustatymai</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Visi</translation>
    </message>
    <message>
        <source>&amp;Show missing helpers</source>
        <translation>&amp;Trūkstamos pagalbinės programos</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Erase search history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sortByDateAsc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by dates from oldest to newest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sortByDateDesc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by dates from newest to oldest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Query Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show results as table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rebuild index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show indexed types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Indexing schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xternal index dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecollModel</name>
    <message>
        <source>File name</source>
        <translation type="unfinished">Bylos vardas</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Mime tipas</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Abstract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Original character set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relevancy rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date and time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ipath</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIME type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResList</name>
    <message>
        <source>Result list</source>
        <translation>Rezultatų sąrašas</translation>
    </message>
    <message>
        <source>(show query)</source>
        <translation>(rodyti užklausą)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Peržiūra</translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation>Kopijuoti &amp;Bylos vardą</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation>Kopijuoti &amp;URL</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation>Rasti &amp;panašius dokumentus</translation>
    </message>
    <message>
        <source>Query details</source>
        <translation type="obsolete">Užklausos detalės</translation>
    </message>
    <message>
        <source>filtered</source>
        <translation type="obsolete">išfiltruota</translation>
    </message>
    <message>
        <source>sorted</source>
        <translation type="obsolete">surūšiuota</translation>
    </message>
    <message>
        <source>Document history</source>
        <translation>Dokumentų istorija</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Nerasta rezultatų&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>Unavailable document</source>
        <translation>Neprieinamas dokumentas</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Peržiūra</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atidaryti</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
        <translation>&lt;p&gt;&lt;i&gt;Kiti galimi tarimai (be akcentų): &lt;/i&gt;</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation>&amp;Įrašyti į bylą</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation>Peržiūrėti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation>Atidaryti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <source>out of at least</source>
        <translation>iš bent</translation>
    </message>
    <message>
        <source>for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResTable</name>
    <message>
        <source>&amp;Reset sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save table to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t open/create file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Peržiūra</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation type="unfinished">Kopijuoti &amp;Bylos vardą</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished">Kopijuoti &amp;URL</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished">&amp;Įrašyti į bylą</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation type="unfinished">Rasti &amp;panašius dokumentus</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished">Peržiūrėti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished">Atidaryti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
    <message>
        <source>&amp;Save as CSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &quot;%1&quot; column</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResTableDetailArea</name>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Peržiūra</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy &amp;File Name</source>
        <translation type="unfinished">Kopijuoti &amp;Bylos vardą</translation>
    </message>
    <message>
        <source>Copy &amp;URL</source>
        <translation type="unfinished">Kopijuoti &amp;URL</translation>
    </message>
    <message>
        <source>&amp;Write to File</source>
        <translation type="unfinished">&amp;Įrašyti į bylą</translation>
    </message>
    <message>
        <source>Find &amp;similar documents</source>
        <translation type="unfinished">Rasti &amp;panašius dokumentus</translation>
    </message>
    <message>
        <source>Preview P&amp;arent document/folder</source>
        <translation type="unfinished">Peržiūrėti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
    <message>
        <source>&amp;Open Parent document/folder</source>
        <translation type="unfinished">Atidaryti &amp;Aukštesnio lygio dokumentus/direktorijas</translation>
    </message>
</context>
<context>
    <name>SSearch</name>
    <message>
        <source>Any term</source>
        <translation>Bet kuris raktinis žodis</translation>
    </message>
    <message>
        <source>All terms</source>
        <translation>Visi raktiniai žodžiai</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Bylos vardas</translation>
    </message>
    <message>
        <source>Query language</source>
        <translation>Užklausų kalba</translation>
    </message>
    <message>
        <source>Bad query string</source>
        <translation>Netinkamai pateikta užklausa</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Nepakanka atminties</translation>
    </message>
    <message>
        <source>Too many completions</source>
        <translation>Per daug galimų užbaigimų</translation>
    </message>
    <message>
        <source>Completions</source>
        <translation>Užbaigimai</translation>
    </message>
    <message>
        <source>Select an item:</source>
        <translation>Pasirinkti įrašą:</translation>
    </message>
    <message>
        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
 Standard field names/synonyms:&lt;br&gt;
  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
 Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
 Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
  No actual parentheses allowed.&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter file name wildcard expression.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Čia įveskite paieškos raktinius žodžius. Įrašykite ESC SPC rašomo termino užbaigimui.</translation>
    </message>
</context>
<context>
    <name>SSearchBase</name>
    <message>
        <source>SSearchBase</source>
        <translation>SSearchBase</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Erase search entry</source>
        <translation>Ištrinti paieškos įrašą</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ieškoti</translation>
    </message>
    <message>
        <source>Start query</source>
        <translation>Pradėti užklausą</translation>
    </message>
    <message>
        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
        <translation>Čia įveskite paieškos raktinius žodžius. Įrašykite ESC SPC rašomo termino užbaigimui.</translation>
    </message>
    <message>
        <source>Choose search type.</source>
        <translation>Pasirinkite paieškos tipą.</translation>
    </message>
</context>
<context>
    <name>SearchClauseW</name>
    <message>
        <source>SearchClauseW</source>
        <translation type="obsolete">SearchClauseW</translation>
    </message>
    <message>
        <source>Any of these</source>
        <translation type="obsolete">Bet kuris šių</translation>
    </message>
    <message>
        <source>All of these</source>
        <translation type="obsolete">Visi šie</translation>
    </message>
    <message>
        <source>None of these</source>
        <translation type="obsolete">Nei vienas šių</translation>
    </message>
    <message>
        <source>This phrase</source>
        <translation type="obsolete">Ši frazė</translation>
    </message>
    <message>
        <source>Terms in proximity</source>
        <translation type="obsolete">Artimi raktiniai žodžiai</translation>
    </message>
    <message>
        <source>File name matching</source>
        <translation type="obsolete">Bylos vardą atitinka</translation>
    </message>
    <message>
        <source>Select the type of query that will be performed with the words</source>
        <translation>Pasirinkite užklausos tipą atliekamą su žodžiais</translation>
    </message>
    <message>
        <source>Number of additional words that may be interspersed with the chosen ones</source>
        <translation>Papildomų žodžių skaičius kurie gali  interspersed with the chosen ones</translation>
    </message>
    <message>
        <source>No field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Visi</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proximity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished">Bylos vardas</translation>
    </message>
</context>
<context>
    <name>SortForm</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Data</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Mime tipas</translation>
    </message>
</context>
<context>
    <name>SortFormBase</name>
    <message>
        <source>Sort Criteria</source>
        <translation type="obsolete">Rūšiavimo kriterijus</translation>
    </message>
    <message>
        <source>Sort the</source>
        <translation type="obsolete">Rūšiuoti</translation>
    </message>
    <message>
        <source>most relevant results by:</source>
        <translation type="obsolete">tinkamiausi rezultatai pagal:</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="obsolete">Mažėjimo tvarka</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Pritaikyti</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="obsolete">Uždaryti</translation>
    </message>
</context>
<context>
    <name>SpellBase</name>
    <message>
        <source>Term Explorer</source>
        <translation>Raktinių žodžių tyrinėjimas</translation>
    </message>
    <message>
        <source>&amp;Expand </source>
        <translation>&amp;Išplėsti</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Uždaryti</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <source>Term</source>
        <translation type="obsolete">Raktinis žodis</translation>
    </message>
    <message>
        <source>No db info.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpellW</name>
    <message>
        <source>Wildcards</source>
        <translation>Wildcards</translation>
    </message>
    <message>
        <source>Regexp</source>
        <translation>Regexp</translation>
    </message>
    <message>
        <source>Stem expansion</source>
        <translation>Stem expansion</translation>
    </message>
    <message>
        <source>Spelling/Phonetic</source>
        <translation>Tarimas/Fonetika</translation>
    </message>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>error retrieving stemming languages</translation>
    </message>
    <message>
        <source>Aspell init failed. Aspell not installed?</source>
        <translation>Aspell iššaukimas nepavyko. Aspell programa neįdiegta?</translation>
    </message>
    <message>
        <source>Aspell expansion error. </source>
        <translation>Aspell praplėtimų klaida.</translation>
    </message>
    <message>
        <source>No expansion found</source>
        <translation>Nerasta praplėtimų</translation>
    </message>
    <message>
        <source>Term</source>
        <translation>Raktinis žodis</translation>
    </message>
    <message>
        <source>Doc. / Tot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Index: %1 documents, average length %2 terms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIPrefsDialog</name>
    <message>
        <source>error retrieving stemming languages</source>
        <translation>error retrieving stemming languages</translation>
    </message>
    <message>
        <source>The selected directory does not appear to be a Xapian index</source>
        <translation>Atrodo, jog pasirinkta direktorija nėra Xapian indekso direktorija</translation>
    </message>
    <message>
        <source>This is the main/local index!</source>
        <translation>Pagrindinis/localus indekas!</translation>
    </message>
    <message>
        <source>The selected directory is already in the index list</source>
        <translation>Pasirinkta direktorija jau yra indekso sąraše</translation>
    </message>
    <message>
        <source>Select xapian index directory (ie: /home/buddy/.recoll/xapiandb)</source>
        <translation>Pasirinkite Xapian indekso direktoriją (pav: /home/buddy/.recoll/xapiandb)</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished">Naršyti</translation>
    </message>
</context>
<context>
    <name>UIPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation type="obsolete">Vartotojo nustatymai</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation type="obsolete">Vartotoja aplinka</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation type="obsolete">Įrašų skaičius rezultatų puslapyje</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation type="obsolete">Rezultatų sąrašo šriftas</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation type="obsolete">Helvetica-10</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation type="obsolete">Pasirinkite rezultatų sąrašo šriftą</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="obsolete">Gražinti numatytąją formą</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation type="obsolete">Gražina numatytąją rezultatų sąrašo srifto vertę</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="obsolete">Rezultatų paragrafo&lt;br&gt;formatas</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Apibūdina kiekvieno rezultatų įrašo formatą:&lt;br&gt;%A Santrauka&lt;br&gt; %D Data&lt;br&gt; %I Ikona&lt;br&gt; %K Raktiniai žodžiai (jei yra)&lt;br&gt; %L Peržiūros ir Redagavimo nuorodos&lt;br&gt; %M Mime tipai&lt;br&gt; %N Rezultų skaičius&lt;br&gt; %R Tinkamumas procentais&lt;br&gt; %S Informacija apie dydį&lt;br&gt; %T Pavadinimas&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation type="obsolete">Tekstai viršijantys šį dydį nebus nuspalvinami peržiūros metu (per didelė apkrova).</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation type="obsolete">Didžiausia teksto, pažymėto peržiūrai, apimtis (megabaitai)</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation type="obsolete">Pradėti paprastąją paiešką įvedus tuščio tarpelio simoblį.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation type="obsolete">Pradėti nuo išsamesnės paieškos lango.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Pradėti su atidarytu rūšiavimo langu.</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation type="obsolete">Naudoti darbalaukio nustatymus parenkant dokumentų redaktorių.</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation type="obsolete">Įsiminti rūšiavimo pasirinkimus (nedings perkrovus).</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation type="obsolete">Paieškos parametrai</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation type="obsolete">Stemming kalba</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation type="obsolete">Pridėti prie paprastos paieškos frazę</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation type="obsolete">Paieška bus pakeista (pav. rolling stones -&gt; rolling or stones or (rolling phrase 2 stones)). Teikiama aiški pirmenybė rezultatams kuriuose rasti raktiniai žodžiai atitinka įvestus.</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation type="obsolete">Dinamiškai sukurti santraukas</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation type="obsolete">Ar pabandome sukurti santraukas remdamiesi užklausų raktinių žodžių kontekstu?
Didelės apimties dokumentams gali lėtai veikti.</translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation type="obsolete">Pakeisti dokumentuose randamas santraukas</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation type="obsolete">Ar sukuriame dirbtinę santrauką, jei dokumente jau ji yra? </translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation type="obsolete">Dirbtinės santraukos dydis (simbolių skaičius)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation type="obsolete">Dirbtinės santraukos konteksto žodžiai</translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation type="obsolete">Išoriniai indeksai</translation>
    </message>
    <message>
        <source>External indexes</source>
        <translation type="obsolete">Išoriniai indeksai</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation type="obsolete">Įjungti/Išjungti pasirinktą</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation type="obsolete">Visus aktyvuoti</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation type="obsolete">Visus deaktyvuoti</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation type="obsolete">Pažymėtus pašalinti</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation type="obsolete">Pašalinti iš sąrašo. Neturi jokio poveikio indeksui diske.</translation>
    </message>
    <message>
        <source>Add index</source>
        <translation type="obsolete">Pridėti indeksą</translation>
    </message>
    <message>
        <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
        <translation type="obsolete">Pasirinkti xapiandb direktoriją kurios indeką norite pridėti, tada paspauskite Pridėti Indeksą</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Naršyti</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Gerai</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation type="obsolete">Pritaikyti pakeitimus</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Atšaukti</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation type="obsolete">Panaikinti pakeitimus</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation type="obsolete">Užklausų raktinių žodžių žymėjimo spalvos</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation type="obsolete">Pirmenybę teikti Html formatui peržiūros metu.</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation type="obsolete">Pažymėjus, bus rodoma tik viena iš bylų su tuo pačiu turiniu, tačiau skirtingais vardais.</translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation type="obsolete">Slėpti pasikartojančius rezultatus.</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation type="obsolete">Pasirinkite redaktorių programas</translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation type="obsolete">Kategorijų filtrą rodyti kaip įrankų juostą (reikalauja perkrovimo).</translation>
    </message>
</context>
<context>
    <name>ViewAction</name>
    <message>
        <source>Changing actions with different current values</source>
        <translation>Pakeisti veiksmus su skirtingomis dabartinėmis vertėmis</translation>
    </message>
    <message>
        <source>Mime type</source>
        <translation type="obsolete">Mime tipas</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIME type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewActionBase</name>
    <message>
        <source>Native Viewers</source>
        <translation>Sistemos peržiūros programos</translation>
    </message>
    <message>
        <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
        <translation>Pasirinkite vieną ar kelis bylų tipus, tada paspauskite Keisti Veiksmus norėdami keisti kaip programa juos atidaro</translation>
    </message>
    <message>
        <source>File type</source>
        <translation type="obsolete">Bylos tipas</translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="obsolete">Veiksmas</translation>
    </message>
    <message>
        <source>Change Action</source>
        <translation>Pakeisti veiksmą</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Uždaryti</translation>
    </message>
    <message>
        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
        <translation>Pasirinkite vieną ar kelis mime tipus tada spauskite &quot;Keisti Veiksmus&quot;&lt;br&gt;Taip pat galite uždaryti šį langą ir patikrinti &quot;Naudoti darbalaukio nustatymus&quot;&lt;br&gt;pagrindinėje panelėje? norėdami ignoruoti šį sąrašą ir naudoti numatytasias darbalaukio.</translation>
    </message>
</context>
<context>
    <name>confgui::ConfBeaglePanelW</name>
    <message>
        <source>Steal Beagle indexing queue</source>
        <translation>Įtraukti Beagle paruoštus duomenis</translation>
    </message>
    <message>
        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
        <translation>BEAGLE programa TURI neveikti. Įgalina peržiūrėti beagle paruoštą medžiagą bandant indeksuoti Firefox naršymo&lt;br&gt; istoriją (papildomai reikia įdiegti Firefox Beagle priedą)</translation>
    </message>
    <message>
        <source>Web cache directory name</source>
        <translation type="obsolete">Naršymo tinkle cache direktorijos vardas</translation>
    </message>
    <message>
        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
        <translation type="obsolete">Direktorijos, kurioje saugoma lankytų tinklo svetainių cache, vardas.&lt;br&gt;Santykinis kelias prasideda nuo nustatymų direktorijos.</translation>
    </message>
    <message>
        <source>Max. size for the web cache (MB)</source>
        <translation type="obsolete">Didžiausias tinklo naršymo cache dydis (MB)</translation>
    </message>
    <message>
        <source>Entries will be recycled once the size is reached</source>
        <translation>Įrašai bus trinami pasiekus nurodytą dydį</translation>
    </message>
    <message>
        <source>Web page store directory name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name for a directory where to store the copies of visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. size for the web store (MB)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>confgui::ConfIndexW</name>
    <message>
        <source>Can&apos;t write configuration file</source>
        <translation>Nepavyksta įrašyti nustatymų bylos</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamFNW</name>
    <message>
        <source>Browse</source>
        <translation type="obsolete">Naršyti</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Naršyti</translation>
    </message>
</context>
<context>
    <name>confgui::ConfParamSLW</name>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>confgui::ConfSubPanelW</name>
    <message>
        <source>Global</source>
        <translation>Globalus</translation>
    </message>
    <message>
        <source>Max. compressed file size (KB)</source>
        <translation>Didžiausias suspaustų bylų dydis (KB)</translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
        <translation>Viršijus pasirinktą suspaustų bylų dydį, jie nebus indeksuojami. Pasirinkite -1 jei nenorite nurodyti ribos, 0, jei nenorite, jog suspaustos bylos būtų indeksuojamos.</translation>
    </message>
    <message>
        <source>Max. text file size (MB)</source>
        <translation>Didžiausias tekstinės bylos dydis (MB)</translation>
    </message>
    <message>
        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
This is for excluding monster log files from the index.</source>
        <translation>Viršijus pasirinktą tekstinių bylų dydį, jie nebus indeksuojami. Pasirinkite -1 jei nenorite nurodyti ribos, 0, jei nenorite, jog suspaustos bylos būtų indeksuojamos.</translation>
    </message>
    <message>
        <source>Text file page size (KB)</source>
        <translation>Tekstinės bylos dydis (KB)</translation>
    </message>
    <message>
        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
This will help searching very big text  files (ie: log files).</source>
        <translation>Jei vertė nurodyta (nelgyi -1) tekstinės bylos bus suskaidytos į nurodyto dydžio bylas, kurios bus atskirai indeksuojamos. Naudinga atliekant paiešką labai dideliose tekstinėse bylose (pav. log bylose).</translation>
    </message>
    <message>
        <source>Max. filter exec. time (S)</source>
        <translation>Ilgiausias filtrų veikimo laikas (S)</translation>
    </message>
    <message>
        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
</source>
        <translation>Išorinių filtrų, dirbančių ilgiau nei numatyta, darbas bus nutraukiamas. Taikoma retiems atvejas (pav. postscript) kada dokumentas galėtų priversti filtrą kartoti veiksmus be galo ilgai. </translation>
    </message>
</context>
<context>
    <name>confgui::ConfTopPanelW</name>
    <message>
        <source>Top directories</source>
        <translation>Aukščiausio lygmens direktorijos&lt;br&gt;kuriose vykdomas indeksavimas</translation>
    </message>
    <message>
        <source>The list of directories where recursive indexing starts. Default: your home.</source>
        <translation>Direktorijų, kuriose pradedamas rekursinis indeksavimas, sąrašas. Numatytoji: namų direktorija.</translation>
    </message>
    <message>
        <source>Skipped paths</source>
        <translation>Direktorijų, kurių turinys nein-&lt;br&gt;deksuojamas, sąrašas</translation>
    </message>
    <message>
        <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
        <translation>Direktorijų, kurių turinys nebus indeksuojamas, vardai.&lt;br&gt; Vardo dalis gali būti wildcards. Turi atitikti programos matomus kelius iki direktorijų (pav. jei indeksuoti pradedama nuo &apos;/home/me&apos;, o &apos;/home&apos; yra nuoroda į &apos;/usr/home&apos;, teisinga vertė bus &apos;/home/me/tmp*&apos;, o ne &apos;/usr/home/me/tm*&apos;)</translation>
    </message>
    <message>
        <source>Stemming languages</source>
        <translation>Kalbos naudojamos stemming&lt;br&gt; procesui</translation>
    </message>
    <message>
        <source>The languages for which stemming expansion&lt;br&gt;dictionaries will be built.</source>
        <translation>Kalbos, kurioms bus sukurti stemming &lt;br&gt;expansion žodynai.</translation>
    </message>
    <message>
        <source>Log file name</source>
        <translation>Log bylos vardas</translation>
    </message>
    <message>
        <source>The file where the messages will be written.&lt;br&gt;Use &apos;stderr&apos; for terminal output</source>
        <translation>Byla, kurioje bus įrašomos žinutės.&lt;br&gt;Naudokite &apos;stderr&apos; norėdami išvesti į terminalo langą</translation>
    </message>
    <message>
        <source>Log verbosity level</source>
        <translation>Log išsamumo lygmuo</translation>
    </message>
    <message>
        <source>This value adjusts the amount of messages,&lt;br&gt;from only errors to a lot of debugging data.</source>
        <translation>Vertė nustato žiniučių apimtį, nuo vien tik &lt;br&gt;klaidų fiksavimo iki didelės apimties duomenų skirtų debugging.</translation>
    </message>
    <message>
        <source>Index flush megabytes interval</source>
        <translation>Indekso dalių, įrašomų į diską, dydis (MB)</translation>
    </message>
    <message>
        <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
        <translation>Vertė nustato duomenų, kurie indeksuojami tarp įrašymo į diską, apimtį.&lt;br&gt;Padeda valdyti indeksavimo dalies atminties naudojimą. Numatyta vertė yra 10 MB</translation>
    </message>
    <message>
        <source>Max disk occupation (%)</source>
        <translation>Didžiausia disko atminties naudojimo dalis (%)</translation>
    </message>
    <message>
        <source>This is the percentage of disk occupation where indexing will fail and stop (to avoid filling up your disk).&lt;br&gt;0 means no limit (this is the default).</source>
        <translation>Viršijus (procentine išraiška) disko atminties panaudojimą indeksavimas bus sustabdytas (vengiant pilnai užpildyti diską).&lt;br&gt;0 reiškia, jog ribos nėra (numatytoji vertė).</translation>
    </message>
    <message>
        <source>No aspell usage</source>
        <translation>Aspell nebus naudojama</translation>
    </message>
    <message>
        <source>Aspell language</source>
        <translation>Aspell kalba</translation>
    </message>
    <message>
        <source>The language for the aspell dictionary. This should look like &apos;en&apos; or &apos;fr&apos; ...&lt;br&gt;If this value is not set, the NLS environment will be used to compute it, which usually works.To get an idea of what is installed on your system, type &apos;aspell config&apos; and look for .dat files inside the &apos;data-dir&apos; directory. </source>
        <translation>Aspell žodyno kalba (&apos;en&apos;, &apos;fr&apos; ar kita).&lt;br&gt;Jei vertė nenurodyta NLS aplinka pabandys nustatyti tinkamą kalbą (paprastai teisingai). Norėdami sužinoti kas įrašyta Jūsų sistemoje įrašykite &apos;aspell-config&apos; ir žiūrėkite į dat bylas &apos;data-dir&apos; direktorijoje.</translation>
    </message>
    <message>
        <source>Database directory name</source>
        <translation>Duomenų bazės direktorijos vardas</translation>
    </message>
    <message>
        <source>The name for a directory where to store the index&lt;br&gt;A non-absolute path is taken relative to the  configuration directory. The default is &apos;xapiandb&apos;.</source>
        <translation>Direktorijos, kurioje bus saugomas indeksas, vardas&lt;br&gt;Laikoma, jog santykinio keliio iki direktorijos pradžia yra nustatymų direktorija. Numatytoji yra &apos;xapiandb&apos;. </translation>
    </message>
    <message>
        <source>Use system&apos;s &apos;file&apos; command</source>
        <translation>Naudoti sistemos &apos;file&apos; komandą</translation>
    </message>
    <message>
        <source>Use the system&apos;s &apos;file&apos; command if internal&lt;br&gt;mime type identification fails.</source>
        <translation>Jei nepavyks atpažinti mime tipo&lt;br&gt;naudoti sistemos &apos;file&apos; komandą. </translation>
    </message>
    <message>
        <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
        <translation>Nurodo nenaudoti aspell programos kuriant tarimo aproksimacijas raktinių žodžių tyrinėjimo įrankyje.&lt;br&gt;Naudinga, jei aspell neveikia arba neįdiegta.</translation>
    </message>
</context>
<context>
    <name>uiPrefsDialogBase</name>
    <message>
        <source>User preferences</source>
        <translation>Vartotojo nustatymai</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Vartotoja aplinka</translation>
    </message>
    <message>
        <source>Number of entries in a result page</source>
        <translation>Įrašų skaičius rezultatų puslapyje</translation>
    </message>
    <message>
        <source>If checked, results with the same content under different names will only be shown once.</source>
        <translation>Pažymėjus, bus rodoma tik viena iš bylų su tuo pačiu turiniu, tačiau skirtingais vardais.</translation>
    </message>
    <message>
        <source>Hide duplicate results.</source>
        <translation>Slėpti pasikartojančius rezultatus.</translation>
    </message>
    <message>
        <source>Highlight color for query terms</source>
        <translation>Užklausų raktinių žodžių žymėjimo spalvos</translation>
    </message>
    <message>
        <source>Result list font</source>
        <translation>Rezultatų sąrašo šriftas</translation>
    </message>
    <message>
        <source>Opens a dialog to select the result list font</source>
        <translation>Pasirinkite rezultatų sąrašo šriftą</translation>
    </message>
    <message>
        <source>Helvetica-10</source>
        <translation>Helvetica-10</translation>
    </message>
    <message>
        <source>Resets the result list font to the system default</source>
        <translation>Gražina numatytąją rezultatų sąrašo srifto vertę</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Gražinti numatytąją formą</translation>
    </message>
    <message>
        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
        <translation type="obsolete">Apibūdina kiekvieno rezultatų įrašo formatą:&lt;br&gt;%A Santrauka&lt;br&gt; %D Data&lt;br&gt; %I Ikona&lt;br&gt; %K Raktiniai žodžiai (jei yra)&lt;br&gt; %L Peržiūros ir Redagavimo nuorodos&lt;br&gt; %M Mime tipai&lt;br&gt; %N Rezultų skaičius&lt;br&gt; %R Tinkamumas procentais&lt;br&gt; %S Informacija apie dydį&lt;br&gt; %T Pavadinimas&lt;br&gt; %U Url&lt;br&gt;</translation>
    </message>
    <message>
        <source>Result paragraph&lt;br&gt;format string</source>
        <translation type="obsolete">Rezultatų paragrafo&lt;br&gt;formatas</translation>
    </message>
    <message>
        <source>Texts over this size will not be highlighted in preview (too slow).</source>
        <translation>Tekstai viršijantys šį dydį nebus nuspalvinami peržiūros metu (per didelė apkrova).</translation>
    </message>
    <message>
        <source>Maximum text size highlighted for preview (megabytes)</source>
        <translation>Didžiausia teksto, pažymėto peržiūrai, apimtis (megabaitai)</translation>
    </message>
    <message>
        <source>Use desktop preferences to choose document editor.</source>
        <translation>Naudoti darbalaukio nustatymus parenkant dokumentų redaktorių.</translation>
    </message>
    <message>
        <source>Choose editor applications</source>
        <translation>Pasirinkite redaktorių programas</translation>
    </message>
    <message>
        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
        <translation>Kategorijų filtrą rodyti kaip įrankų juostą (reikalauja perkrovimo).</translation>
    </message>
    <message>
        <source>Auto-start simple search on whitespace entry.</source>
        <translation>Pradėti paprastąją paiešką įvedus tuščio tarpelio simoblį.</translation>
    </message>
    <message>
        <source>Start with advanced search dialog open.</source>
        <translation>Pradėti nuo išsamesnės paieškos lango.</translation>
    </message>
    <message>
        <source>Start with sort dialog open.</source>
        <translation type="obsolete">Pradėti su atidarytu rūšiavimo langu.</translation>
    </message>
    <message>
        <source>Remember sort activation state.</source>
        <translation>Įsiminti rūšiavimo pasirinkimus (nedings perkrovus).</translation>
    </message>
    <message>
        <source>Prefer Html to plain text for preview.</source>
        <translation>Pirmenybę teikti Html formatui peržiūros metu.</translation>
    </message>
    <message>
        <source>Search parameters</source>
        <translation>Paieškos parametrai</translation>
    </message>
    <message>
        <source>Stemming language</source>
        <translation>Stemming kalba</translation>
    </message>
    <message>
        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
This should give higher precedence to the results where the search terms appear exactly as entered.</source>
        <translation>Paieška bus pakeista (pav. rolling stones -&gt; rolling or stones or (rolling phrase 2 stones)). Teikiama aiški pirmenybė rezultatams kuriuose rasti raktiniai žodžiai atitinka įvestus.</translation>
    </message>
    <message>
        <source>Automatically add phrase to simple searches</source>
        <translation>Pridėti prie paprastos paieškos frazę</translation>
    </message>
    <message>
        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
May be slow for big documents.</source>
        <translation>Ar pabandome sukurti santraukas remdamiesi užklausų raktinių žodžių kontekstu?
Didelės apimties dokumentams gali lėtai veikti.</translation>
    </message>
    <message>
        <source>Dynamically build abstracts</source>
        <translation>Dinamiškai sukurti santraukas</translation>
    </message>
    <message>
        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
        <translation>Ar sukuriame dirbtinę santrauką, jei dokumente jau ji yra? </translation>
    </message>
    <message>
        <source>Replace abstracts from documents</source>
        <translation>Pakeisti dokumentuose randamas santraukas</translation>
    </message>
    <message>
        <source>Synthetic abstract size (characters)</source>
        <translation>Dirbtinės santraukos dydis (simbolių skaičius)</translation>
    </message>
    <message>
        <source>Synthetic abstract context words</source>
        <translation>Dirbtinės santraukos konteksto žodžiai</translation>
    </message>
    <message>
        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Query language magic file name suffixes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External Indexes</source>
        <translation>Išoriniai indeksai</translation>
    </message>
    <message>
        <source>Toggle selected</source>
        <translation>Įjungti/Išjungti pasirinktą</translation>
    </message>
    <message>
        <source>Activate All</source>
        <translation>Visus aktyvuoti</translation>
    </message>
    <message>
        <source>Deactivate All</source>
        <translation>Visus deaktyvuoti</translation>
    </message>
    <message>
        <source>Remove from list. This has no effect on the disk index.</source>
        <translation>Pašalinti iš sąrašo. Neturi jokio poveikio indeksui diske.</translation>
    </message>
    <message>
        <source>Remove selected</source>
        <translation>Pažymėtus pašalinti</translation>
    </message>
    <message>
        <source>Click to add another index directory to the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add index</source>
        <translation>Pridėti indeksą</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Pritaikyti pakeitimus</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Gerai</translation>
    </message>
    <message>
        <source>Discard changes</source>
        <translation>Panaikinti pakeitimus</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Atšaukti</translation>
    </message>
    <message>
        <source>Abstract snippet separator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opens a dialog to select the style sheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose</source>
        <translation type="unfinished">Naršyti</translation>
    </message>
    <message>
        <source>Resets the style sheet to default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines in PRE text are not folded. Using BR loses some indentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &lt;PRE&gt; tags instead of &lt;BR&gt;to display plain text as html in preview.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit result paragraph format string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit result page html header insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date format (strftime(3))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency percentage threshold over which we do not use terms inside autophrase. 
Frequent terms are a major performance issue with phrases. 
Skipped terms augment the phrase slack, and reduce the autophrase efficiency.
The default value is 2 (percent). </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autophrase term frequency threshold percentage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
